/**
 * Represents a stock quote.
 */
export class Quote {
    /**
     * The name of the company associated with this quote.
     */
    readonly companyName: string;

    /**
     * The earnings per share of a company.
     */
    readonly earningsPerShare: number;

    /**
     * The estimated earnings for a stock.
     */
    readonly estimatedEarnings: number;

    /**
     * The price of the last trade for the security.
     */
    readonly lastTrade: number;

    /**
     * The symbol of the financial instrument being quoted.
     */
    readonly symbol: string;

    /**
     * Represents a quote for a particular stock.
     * @constructor
     * @param {string} companyName - The name of the company associated with the stock.
     * @param {number} earningsPerShare - The earnings per share for the stock.
     * @param {number} estimatedEarnings - The estimated earnings for the stock.
     * @param {number} lastTrade - The last trade price for the stock.
     * @param {string} symbol - The symbol for the stock.
     */
    constructor(
        companyName: string,
        earningsPerShare: number,
        estimatedEarnings: number,
        lastTrade: number,
        symbol: string
    ) {
        this.companyName = companyName;
        this.earningsPerShare = earningsPerShare;
        this.estimatedEarnings = estimatedEarnings;
        this.lastTrade = lastTrade;
        this.symbol = symbol;
    }
}

/**
 * A provider for fetching stock quotes.
 */
export interface QuoteProvider {

    /**
     * Fetches a quote for the given stock symbol.
     * @param symbol The stock symbol to fetch the quote for.
     * @returns A Promise that resolves to a Quote object.
     */
    readonly fetchQuote: (symbol: string) => Promise<Quote>;
}
